@@ -3,11 +3,15 @@
 
 __author__ = 'zeus'
 from django.conf import settings
+from utils import get_model_string
 
 def imagestore_processor(request):
     template = getattr(settings, 'IMAGESTORE_TEMPLATE', False)
-    imagestore_show_user = getattr(settings, 'IMAGESTORE_SHOW_USER', True)
-    ret = {'IMAGESTORE_SHOW_USER': imagestore_show_user,}
+    ret = {
+        'IMAGESTORE_SHOW_USER': getattr(settings, 'IMAGESTORE_SHOW_USER', True),
+        'IMAGESTORE_SHOW_TAGS': getattr(settings, 'IMAGESTORE_SHOW_TAGS', True),
+        'IMAGESTORE_MODEL_STRING': get_model_string('Image')
+        }
     if template:
         ret['IMAGESTORE_TEMPLATE'] = template
     return ret
